@@ -386,6 +386,24 @@ struct isoburn_imgen_opts {
      * but it is supposed to work on most moderns systems. Use with caution.
      */
 
+    /*
+     * Extra Caution: This option breaks any assumptions about names that
+     *                are supported by ECMA-119 specifications.
+     * Omit any translation which would make a file name compliant to the
+     * ECMA-119 rules. This includes and exceeds omit_version_numbers,
+     * max_37_char_filenames, no_force_dots bit0, allow_lowercase.
+     */
+    unsigned int untranslated_name_len;
+
+    /*
+     * Convert directory names for ECMA-119 similar to other file names, but do
+     * not force a dot or add a version number.
+     * This violates ECMA-119 by allowing one "." and especially ISO level 1
+     * by allowing DOS style 8.3 names rather than only 8 characters.
+     * (mkisofs and its clones seem to do this violation.)
+     */
+    unsigned int allow_dir_id_ext :1;
+
     /**
      * Omit the version number (";1") at the end of the ISO-9660 identifiers.
      * Version numbers are usually not used.
