@@ -2,7 +2,7 @@
 /*
   Lower level API definition of libisoburn.
 
-  Copyright 2007-2010 Vreixo Formoso Lopes <metalpain2002@yahoo.es>
+  Copyright 2007-2011 Vreixo Formoso Lopes <metalpain2002@yahoo.es>
                   and Thomas Schmitt <scdbackup@gmx.net>
   Provided under GPL version 2 or later.
 */
@@ -222,17 +222,17 @@ void isoburn_version(int *major, int *minor, int *micro);
     at compile time.
     @since 0.1.0
 */
-#define isoburn_libisofs_req_major  0
-#define isoburn_libisofs_req_minor  6
-#define isoburn_libisofs_req_micro 40 
+#define isoburn_libisofs_req_major  1
+#define isoburn_libisofs_req_minor  0
+#define isoburn_libisofs_req_micro  0 
 
 /** The minimum version of libburn to be used with this version of libisoburn
     at compile time.
     @since 0.1.0
 */
-#define isoburn_libburn_req_major  0
-#define isoburn_libburn_req_minor  8
-#define isoburn_libburn_req_micro  8
+#define isoburn_libburn_req_major  1
+#define isoburn_libburn_req_minor  0
+#define isoburn_libburn_req_micro  0
 
 /** The minimum compile time requirements of libisoburn towards libjte are
     the same as of a suitable libisofs towards libjte.
@@ -285,9 +285,9 @@ int isoburn_libburn_req(int *major, int *minor, int *micro);
     time.
     @since 0.1.0
 */
-#define isoburn_header_version_major  0
-#define isoburn_header_version_minor  6
-#define isoburn_header_version_micro  6
+#define isoburn_header_version_major  1
+#define isoburn_header_version_minor  0
+#define isoburn_header_version_micro  0
 /** Note:
     Above version numbers are also recorded in configure.ac because libtool
     wants them as parameters at build time.
@@ -952,6 +952,7 @@ int isoburn_igopt_destroy(struct isoburn_imgen_opts **o, int flag);
     @param level is a term of the ISO 9660 standard. It should be one of:
                  1= filenames restricted to form 8.3
                  2= filenames allowed up to 31 characters
+                 3= file content may be larger than 4 GB - 1.
     @return      1 success, <=0 failure
 */
 int isoburn_igopt_set_level(struct isoburn_imgen_opts *o, int level);
@@ -1089,6 +1090,14 @@ int isoburn_igopt_get_extensions(struct isoburn_imgen_opts *o, int *ext);
                  Joliet tree rather than the ISO 9660 / ECMA-119 names.
                  @since 0.5.4
                  Previous versions added dots to Joliet names unconditionally.
+          bit14= allow_dir_id_ext
+                 Convert directory names for ECMA-119 similar to other file
+                 names, but do not force a dot or add a version number.
+                 This violates ECMA-119 by allowing one "." and especially
+                 ISO level 1 by allowing DOS style 8.3 names rather than
+                 only 8 characters.
+                 (mkisofs and its clones obviously do this violation.)
+                 @since 1.0.0
     @return 1 success, <=0 failure
 */
 #define isoburn_igopt_omit_version_numbers       1
@@ -1105,10 +1114,40 @@ int isoburn_igopt_get_extensions(struct isoburn_imgen_opts *o, int *ext);
 #define isoburn_igopt_aaip_susp_1_10          2048
 #define isoburn_igopt_only_iso_versions       4096
 #define isoburn_igopt_no_j_force_dots         8192
+#define isoburn_igopt_allow_dir_id_ext       16384
 int isoburn_igopt_set_relaxed(struct isoburn_imgen_opts *o, int relax);
 int isoburn_igopt_get_relaxed(struct isoburn_imgen_opts *o, int *relax);
 
 
+/** Caution: This option breaks any assumptions about names that
+             are supported by ECMA-119 specifications.
+    Try to omit any translation which would make a file name compliant to the
+    ECMA-119 rules. This includes and exceeds omit_version_numbers,
+    max_37_char_filenames, no_force_dots bit0, allow_full_ascii. Further it
+    prevents the conversion from local character set to ASCII.
+    The maximum name length is given by this call. If a filename exceeds
+    this length or cannot be recorded untranslated for other reasons, then
+    image production gets aborted.
+    Currently the length limit is 96 characters, because an ECMA-119 directory
+    record may at most have 254 bytes and up to 158 other bytes must fit into
+    the record. Probably 96 more bytes can be made free for the name in future.
+    @since 1.0.0
+    @param o    The option set to work on
+    @param len  0 = disable this feature and perform name translation
+                    according to other settings.
+               >0 = Omit any translation. Eventually abort image production
+                    if a name is longer than the given value.
+               -1 = Like >0. Allow maximum possible length.
+                    isoburn_igopt_get_untranslated_name_len() will tell the
+                    effectively resulting value.
+    @return >0 success, <=0 failure
+*/
+int isoburn_igopt_set_untranslated_name_len(struct isoburn_imgen_opts *o,
+                                            int len);
+int isoburn_igopt_get_untranslated_name_len(struct isoburn_imgen_opts *o,
+                                            int *len);
+
+
 /** Whether and how files should be sorted.
     @since 0.1.0
     @param o     The option set to work on
@@ -1165,7 +1204,7 @@ int isoburn_igopt_get_over_ugid(struct isoburn_imgen_opts *o,
                                int *replace_uid, int *replace_gid,
                                uid_t *uid, gid_t *gid);
 
-/** Set the charcter set to use for representing filenames in the image.
+/** Set the charcter set to use for representing RR filenames in the image.
     @since 0.1.0
     @param o              The option set to work on
     @param output_charset Set this to NULL to use the default output charset.
