@@ -36,7 +36,7 @@
  */
 int iso_image_new(const char *name, IsoImage **image)
 {
-    int res;
+    int res, i;
     IsoImage *img;
 
     if (image == NULL) {
@@ -80,6 +80,9 @@ int iso_image_new(const char *name, IsoImage **image)
     }
     img->system_area_data = NULL;
     img->system_area_options = 0;
+    img->num_mips_boot_files = 0;
+    for (i = 0; i < 15; i++)
+         img->mips_boot_file_paths[i] = NULL;
     img->builder_ignore_acl = 1;
     img->builder_ignore_ea = 1;
     img->inode_counter = 0;
@@ -89,6 +92,7 @@ int iso_image_new(const char *name, IsoImage **image)
     img->checksum_end_lba = 0;
     img->checksum_idx_count = 0;
     img->checksum_array = NULL;
+    img->generator_is_running = 0;
     *image = img;
     return ISO_SUCCESS;
 }
@@ -102,7 +106,7 @@ void iso_image_ref(IsoImage *image)
 }
 
 /**
- * Decrements the reference couting of the given image.
+ * Decrements the reference counting of the given image.
  * If it reaches 0, the image is free, together with its tree nodes (whether
  * their refcount reach 0 too, of course).
  */
@@ -126,6 +130,7 @@ void iso_image_unref(IsoImage *image)
         iso_node_builder_unref(image->builder);
         iso_filesystem_unref(image->fs);
         el_torito_boot_catalog_free(image->bootcat);
+        iso_image_give_up_mips_boot(image, 0);
         free(image->volset_id);
         free(image->volume_id);
         free(image->publisher_id);
@@ -607,3 +612,46 @@ int iso_image_set_checksums(IsoImage *image, char *checksum_array,
     return 1;
 }
 
+int iso_image_generator_is_running(IsoImage *image)
+{
+    return image->generator_is_running;
+}
+
+
+/* API */
+int iso_image_add_mips_boot_file(IsoImage *image, char *path, int flag)
+{
+    if (image->num_mips_boot_files >= 15)
+        return ISO_BOOT_TOO_MANY_MIPS;
+    image->mips_boot_file_paths[image->num_mips_boot_files] = strdup(path);
+    if (image->mips_boot_file_paths[image->num_mips_boot_files] == NULL)
+        return ISO_OUT_OF_MEM;
+    image->num_mips_boot_files++;
+    return ISO_SUCCESS;
+}
+
+/* API */
+int iso_image_get_mips_boot_files(IsoImage *image, char *paths[15], int flag)
+{
+    int i;
+
+    for (i = 0; i < image->num_mips_boot_files; i++)
+         paths[i] = image->mips_boot_file_paths[i];
+    for (; i < 15; i++)
+         paths[i] = NULL;
+    return image->num_mips_boot_files;
+}
+
+/* API */
+int iso_image_give_up_mips_boot(IsoImage *image, int flag)
+{
+    int i;
+
+    for (i = 0; i < image->num_mips_boot_files; i++)
+        if (image->mips_boot_file_paths[i] != NULL) {
+            free(image->mips_boot_file_paths[i]);
+            image->mips_boot_file_paths[i] = NULL;
+        }
+    image->num_mips_boot_files = 0;
+    return ISO_SUCCESS;
+}
