@@ -54,4 +54,10 @@ struct joliet_node
  */
 int joliet_writer_create(Ecma119Image *target);
 
+
+/* Not to be called but only for comparison with target->writers[i]
+*/
+int joliet_writer_write_vol_desc(IsoImageWriter *writer);
+
+
 #endif /* LIBISO_JOLIET_H */
