@@ -640,6 +640,16 @@ int Xorriso_lst_detach_text(struct Xorriso_lsT *entry, int flag)
 }
 
 
+int Xorriso_lst_get_last(struct Xorriso_lsT *entry, struct Xorriso_lsT **last,
+                         int flag)
+{
+ *last= NULL;
+ if(entry != NULL)
+   for((*last)= entry; (*last)->next != NULL; (*last)= (*last)->next);
+ return(1);
+} 
+
+
 /* --------------------------- End Xorriso_lsT ---------------------------- */
 
 
