@@ -3,7 +3,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2010 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -119,7 +119,9 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->split_size= 0;
  strcpy(m->list_delimiter, "--");
  m->ino_behavior= 7;
+ m->iso_level= 3;
  m->do_joliet= 0;
+ m->do_iso1999= 0;
  m->do_aaip= 0;
  m->do_md5= 0;
  m->no_emul_toc= 0;
@@ -128,6 +130,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->scdbackup_tag_written[0]= 0;
  m->scdbackup_tag_listname[0]= 0;
  m->relax_compliance= 0;
+ m->untranslated_name_len= 0;
  m->do_follow_pattern= 1;
  m->do_follow_param= 0;
  m->do_follow_links= 0;
@@ -285,8 +288,9 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  strcpy(m->report_about_text, "UPDATE");
  Xorriso__text_to_sev(m->report_about_text, &m->report_about_severity, 0);
  m->library_msg_direct_print= 0;
- strcpy(m->abort_on_text,"FATAL");
+ strcpy(m->abort_on_text,"FAILURE");
  Xorriso__text_to_sev(m->abort_on_text, &m->abort_on_severity, 0);
+ m->abort_on_is_default= 1;
  m->problem_status= 0;
  m->problem_status_text[0]= 0;
  m->errfile_log[0]= 0;
