@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2010 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -359,7 +359,7 @@ no_volunteer:;
  /* Perform actions */
  Xorriso_option_report_about(xorriso, "NOTE", 0);
  if(do_version) {
-   sprintf(xorriso->result_line, "Cdrecord 2.01-Emulation Copyright (C) 2010 see libburnia-project.org xorriso\n");
+   sprintf(xorriso->result_line, "Cdrecord 2.01-Emulation Copyright (C) 2011 see libburnia-project.org xorriso\n");
    Xorriso_result(xorriso, 1);
    Xorriso_option_version(xorriso, 0);
    ret= 1; goto ex;
@@ -533,6 +533,7 @@ int Xorriso_genisofs_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "-no-mac-files", "-chrp-boot",
     "--hardlinks", "--acl", "--xattr", "--md5", "--for_backup",
     "--protective-msdos-label", "--boot-catalog-hide", "--no-emul-toc",
+    "--emul-toc", "-disallow_dir_id_ext",
     ""
  };
  static char arg1_options[][41]= {
@@ -563,7 +564,7 @@ int Xorriso_genisofs_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "-checksum_algorithm_iso", "-checksum_algorithm_template",
     "--stdio_sync", "--quoted_path_list", "--efi-boot", "--embedded-boot",
     "-isohybrid-mbr", "-e", "-partition_offset", "-partition_hd_cyl",
-    "-partition_sec_hd",
+    "-partition_sec_hd", "-untranslated_name_len",
     ""
  };
  static char arg2_options[][41]= {
@@ -682,10 +683,12 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  -hide-joliet-list FILE      File with list of Joliet files to hide",
 "  -input-charset CHARSET      Local input charset for file name conversion",
 "  -output-charset CHARSET     Output charset for file name conversion",
-"  -iso-level LEVEL            Set ISO9660 conformance level (1..3)",
+"  -iso-level LEVEL            Set ISO9660 conformance level (1..3) or 4 for ISO9660 version 2",
+"  -disallow_dir_id_ext        Do not allow dot in ISO directory names",
 "  -J, -joliet                 Generate Joliet directory information",
 "  -joliet-long                Allow Joliet file names to be 103 Unicode characters",
 "  -U, -untranslated-filenames Allow Untranslated filenames (for HPUX & AIX - violates ISO9660).",
+"  -untranslated_name_len LEN  Allow up to LEN (1..96) name characters (heavily violates ISO9660).",
 "  -allow-lowercase            Allow lower case characters in addition to the current character set (violates ISO9660)",
 "  -d, -omit-period            Omit trailing periods from filenames (violates ISO9660)",
 "  -l, -full-iso9660-filenames Allow full 31 character filenames for ISO9660 names",
@@ -769,6 +772,7 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  --sort-weight NUMBER FILE   Set LBA weight number to file or file tree",
 "  --stdio_sync on|off|number  Control forced output to disk files",
 "  --no-emul-toc               Save 64 kB size on random access output files",
+"  --emul-toc                  Multi-session history on such output files",
 "  -z, -transparent-compression",
 "                              Enable transparent compression of files",
 "  -v, -verbose                Verbose",
@@ -875,11 +879,11 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
                      int argc, char **argv, int flag)
 {
  int ret, i, j, was_path= 0, was_other_option= 0, mem_graft_points, mem;
- int do_print_size= 0, fd, idx, iso_level= 0, emul_boot= 2;
+ int do_print_size= 0, fd, idx, iso_level= 1, emul_boot= 2;
  int option_b= 0, was_failure= 0, fret, lower_r= 0, zero= 0;
- int dir_mode= -1, file_mode= -1, count, partition_number;
+ int dir_mode= -1, file_mode= -1, count, partition_number, allow_dir_id_ext= 1;
  mode_t mode_and, mode_or;
- int with_boot_image= 0, with_cat_path= 0;
+ int with_boot_image= 0, with_cat_path= 0, with_emul_toc= 0;
  int *weight_list= NULL, weight_count= 0;
  int *delay_opt_list= NULL, delay_opt_count= 0;
  char sfe[5*SfileadrL], adr[SfileadrL+8], ra_text[80], pathspec[2*SfileadrL];
@@ -910,7 +914,7 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
  continue;
    if(strcmp(argv[i], "-version")==0) {
      sprintf(xorriso->result_line,
-"mkisofs 2.01-Emulation Copyright (C) 2010 see libburnia-project.org xorriso\n"
+"mkisofs 2.01-Emulation Copyright (C) 2011 see libburnia-project.org xorriso\n"
             );
      fd= xorriso->dev_fd_1;
      if(fd<0)
@@ -960,18 +964,21 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
        goto not_enough_args;
      i++;
      sscanf(argv[i], "%d", &iso_level);
-     if(iso_level < 1 || iso_level > 3) {
+     if(iso_level < 1 || iso_level > 4) {
        sprintf(xorriso->info_text,
-               "-as %s: unsupported -iso-level '%s' (use one of: 1,2,3)",
+               "-as %s: unsupported -iso-level '%s' (use one of: 1,2,3,4)",
                whom, argv[i]);
        Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
        ret= 0; goto problem_handler_1;
      }
-     if(iso_level < 3)
-       xorriso->file_size_limit=
-                          ((off_t) 4) * ((off_t) 1024*1024*1024) - ((off_t) 1);
-     else
-       xorriso->file_size_limit= 0;
+     if(iso_level == 4)
+       xorriso->do_iso1999= 1;
+     else {
+       sprintf(sfe, "iso_9660_level=%s", argv[i]);
+       ret= Xorriso_relax_compliance(xorriso, sfe, 0);
+       if(ret <= 0)
+         goto problem_handler_1;
+     }
 
    } else if(strcmp(argv[i], "-input-charset")==0) {
      if(i+1>=argc)
@@ -1042,6 +1049,14 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
        goto not_enough_args;
      i++;
      Xorriso_option_stdio_sync(xorriso, argv[i], 0);
+   } else if(strcmp(argv[i], "-disallow_dir_id_ext")==0) {
+     allow_dir_id_ext= 0;
+   } else if(strcmp(argv[i], "--emul-toc")==0) {
+     with_emul_toc= 1;
+     xorriso->no_emul_toc&= ~1;
+   } else if(strcmp(argv[i], "--no-emul-toc")==0) {
+     with_emul_toc= 0;
+     xorriso->no_emul_toc|= 1;
    } else
      was_other_option= 1;
      ret= Xorriso_genisofs_count_args(xorriso, argc - i, argv + i, &count, 0);
@@ -1171,10 +1186,12 @@ not_enough_args:;
    } else if(strcmp(argv[i], "-o")==0) {
      i++;
      /* was already handled in first argument scan */;
-   } else if(strcmp(argv[i], "-M")==0  || strcmp(argv[i], "-dev")==0) {
+   } else if(strcmp(argv[i], "-M")==0  || strcmp(argv[i], "-dev")==0 ||
+             strcmp(argv[i], "-prev-session")==0) {
      i++;
      /* was already handled in first argument scan */;
-   } else if(strcmp(argv[i], "-C")==0) {
+   } else if(strcmp(argv[i], "-C")==0 ||
+             strcmp(argv[i], "-cdrecord-params")==0) {
      i++;
      /* was already handled in first argument scan */;
    } else if(strcmp(argv[i], "-help")==0) {
@@ -1303,12 +1320,18 @@ not_enough_args:;
    } else if(strcmp(argv[i], "-z")==0 ||
              strcmp(argv[i], "-transparent-compression")==0) {
      /* was already handled in first argument scan */;
-   } else if(strcmp(argv[i], "--no-emul-toc")==0) {
-     xorriso->no_emul_toc|= 1;
    } else if(strcmp(argv[i], "-U") == 0 ||
              strcmp(argv[i], "-untranslated-filenames") == 0) {
      Xorriso_relax_compliance(xorriso,
               "no_force_dots:long_paths:omit_version:full_ascii:lowercase", 0);
+   } else if(strcmp(argv[i], "-untranslated_name_len") == 0) {
+     if(i+1>=argc)
+       goto not_enough_args;
+     i++;
+     sprintf(sfe, "untranslated_name_len=%s", argv[i]);
+     ret= Xorriso_relax_compliance(xorriso, sfe, 0);
+     if(ret <= 0)
+       goto problem_handler_2;
    } else if(strcmp(argv[i], "-N") == 0 ||
              strcmp(argv[i], "-omit-version-number") == 0) {
      Xorriso_relax_compliance(xorriso, "omit_version", 0);
@@ -1421,6 +1444,19 @@ not_enough_args:;
      strncpy(xorriso->ascii_disc_label, argv[i], Xorriso_disc_label_sizE - 1);
      xorriso->ascii_disc_label[Xorriso_disc_label_sizE - 1] = 0;
 
+   } else if(strcmp(argv[i], "--stdio_sync")==0) {
+     if(i+1>=argc)
+       goto not_enough_args;
+     i++;
+     /* was already handled in first argument scan */;
+
+   } else if(strcmp(argv[i], "--emul-toc")==0 ||
+             strcmp(argv[i], "--no-emul-toc")==0) {
+     /* was already handled in first argument scan */;
+
+   } else if(strcmp(argv[i], "-disallow_dir_id_ext")==0) {
+     /* was already handled in first argument scan */;
+
    } else if(argv[i][0]=='-' && argv[i][1]!=0) {
      ret= Xorriso_genisofs_count_args(xorriso, argc - i, argv + i, &count, 1);
      if(ret > 0) {
@@ -1465,7 +1501,22 @@ is_pathspec_2:;
      if(ret<=0)
        goto problem_handler_2;
      was_path= 1;
+
+     /* Enforce odd mkisofs defaults on first pathspec */
      xorriso->pacifier_style= 1;
+     if(allow_dir_id_ext == 1) {
+       Xorriso_relax_compliance(xorriso, "allow_dir_id_ext", 0);
+       allow_dir_id_ext= 2;
+     }
+     if(iso_level >= 1 && iso_level <= 3) {
+       sprintf(sfe, "iso_9660_level=%d", iso_level);
+       Xorriso_relax_compliance(xorriso, sfe, 0);
+       iso_level= 0;
+     }
+     /* For the sake of compatibility give up emulated multi-session by default
+     */
+     if(with_emul_toc == 0)
+       xorriso->no_emul_toc|= 1;
    }
  continue; /* regular bottom of loop */
 problem_handler_2:;
@@ -1475,10 +1526,6 @@ problem_handler_2:;
  continue;
    goto ex;
  }
- if(do_print_size) {
-   ret= Xorriso_option_print_size(xorriso, 1);
-   goto ex;
- }
  if(lower_r) {
    static char *lower_r_args[3]= {"/", "-exec", "mkisofs_r"};
    zero= 0;
@@ -1673,6 +1720,11 @@ problem_handler_boot:;
      was_failure= 1;
  }
 
+ if(do_print_size) {
+   ret= Xorriso_option_print_size(xorriso, 1);
+   goto ex;
+ }
+
  ret= !was_failure;
 ex:;
  if(was_path && !do_print_size)
