@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2010 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -1473,6 +1473,8 @@ int Xorriso_dialog(struct XorrisO *xorriso, int flag)
 
  if(!xorriso->dialog)
    return(1);
+ if(xorriso->abort_on_is_default)
+   Xorriso_option_abort_on(xorriso, "NEVER", 0);
  xorriso->is_dialog= 1;
  for(first_round= 1;1;first_round= 0) {
    if(xorriso->pending_option[0]!=0) {
