@@ -98,10 +98,11 @@ int Xorriso_sanitize_image_size(struct XorrisO *xorriso,
                     struct burn_write_opts *burn_options, int flag)
 {
  int ret, img_sectors, num_sessions= 0, num_tracks= 0, padding= 0, profile;
- int media_space, lba, nwa;
+ int media_space, lba, nwa, multi_emul_blocks= 0;
  char profile_name[80];
  struct burn_session **sessions;
  struct burn_track **tracks;
+ enum burn_disc_status s;
 
  img_sectors= burn_disc_get_sectors(disc);
 
@@ -140,6 +141,15 @@ no_track:;
         sessions survive and confuse -rom_toc_scan.
       */
      xorriso->alignment= 32;
+
+     s= isoburn_disc_get_status(drive);
+     if(s == BURN_DISC_BLANK) {
+       /* Count blocks before nwa as part of the image */;
+       ret= isoburn_disc_track_lba_nwa(drive, burn_options, 0, &lba, &nwa);
+       if(ret <= 0)
+         nwa= 0;
+       multi_emul_blocks= nwa;
+     }
    }
  }
  if(xorriso->alignment > 0) {
@@ -176,7 +186,7 @@ no_track:;
    {ret= 0; goto ex;}
  }
  if(flag&1) {
-   ret= img_sectors+padding;
+   ret= multi_emul_blocks + img_sectors + padding;
  } else
    ret= 1;
 ex:;
@@ -719,9 +729,10 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
                     &value_length, &value, 2 | 8);
  }
 
- isoburn_igopt_set_level(sopts, 3);
+ isoburn_igopt_set_level(sopts, xorriso->iso_level);
  ext= isoburn_igopt_rockridge |
       ((!!xorriso->do_joliet) * isoburn_igopt_joliet) |
+      ((!!xorriso->do_iso1999) * isoburn_igopt_iso1999) |
       (( !(xorriso->ino_behavior & 2)) * isoburn_igopt_hardlinks) |
       (( (!(xorriso->ino_behavior & 2)) ||
          (xorriso->do_aaip & (2 | 8 | 16 | 256)) ||
@@ -735,6 +746,10 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
    ext|= isoburn_igopt_no_emul_toc;
  isoburn_igopt_set_extensions(sopts, ext);
  isoburn_igopt_set_relaxed(sopts, relax);
+ ret= isoburn_igopt_set_untranslated_name_len(sopts,
+                                              xorriso->untranslated_name_len);
+ if(ret <= 0)
+   {ret= 0; goto ex;}
  isoburn_igopt_set_sort_files(sopts, 1);
  isoburn_igopt_set_over_mode(sopts, 0, 0, (mode_t) 0, (mode_t) 0);
  isoburn_igopt_set_over_ugid(sopts, 0, 0, (uid_t) 0, (gid_t) 0);
@@ -903,6 +918,7 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
    ret= 0; goto ex;
  }
+ Xorriso_process_msg_queues(xorriso,0);
 
  sessions= burn_disc_get_sessions(disc, &num_sessions);
  if(num_sessions>0) {
@@ -1798,7 +1814,10 @@ int Xorriso_relax_compliance(struct XorrisO *xorriso, char *mode,
                                     int flag)
 {
  char *npt, *cpt;
- int l, was;
+ int l, was, value, ret;
+ struct isoburn_imgen_opts *opts= NULL;
+ char msg[160];
+ off_t limit;
 
  was= xorriso->relax_compliance;
  npt= cpt= mode;
@@ -1816,6 +1835,32 @@ int Xorriso_relax_compliance(struct XorrisO *xorriso, char *mode,
    } else if(l == 7 && strncmp(cpt, "default", l) == 0) {
      xorriso->relax_compliance= Xorriso_relax_compliance_defaulT;
 
+   } else if((l == 18 && strncmp(cpt, "untranslated_names", l) == 0) ||
+             (l == 21 && strncmp(cpt, "untranslated_names_on", l) == 0) ) {
+     xorriso->untranslated_name_len = -1;
+   } else if((l == 22 && strncmp(cpt, "untranslated_names_off", l) == 0)) {
+     xorriso->untranslated_name_len = 0;
+   } else if((l >= 22 && strncmp(cpt, "untranslated_name_len=", 22) == 0)) {
+     value= -1;
+     sscanf(cpt + 22, "%d", &value);
+     /* Let libisoburn check the value */
+     ret= isoburn_igopt_new(&opts, 0);
+     if(ret != 1)
+       return(-1);
+     ret= isoburn_igopt_set_untranslated_name_len(opts, value);
+     isoburn_igopt_destroy(&opts, 0);
+     if(ret <= 0) { /* Not a tasty value */
+       xorriso->relax_compliance= was;
+       return(0);
+     }
+     xorriso->untranslated_name_len = value;
+
+   } else if((l == 16 && strncmp(cpt, "allow_dir_id_ext", l) == 0) ||
+             (l == 19 && strncmp(cpt, "allow_dir_id_ext_on", l) == 0) ) {
+     xorriso->relax_compliance|= isoburn_igopt_allow_dir_id_ext;
+   } else if((l == 20 && strncmp(cpt, "allow_dir_id_ext_off", l) == 0)) {
+     xorriso->relax_compliance&= ~isoburn_igopt_allow_dir_id_ext;
+
    } else if((l == 12 && strncmp(cpt, "omit_version", l) == 0) ||
              (l == 15 && strncmp(cpt, "omit_version_on", l) == 0) ) {
      xorriso->relax_compliance|= isoburn_igopt_omit_version_numbers;
@@ -1915,6 +1960,33 @@ int Xorriso_relax_compliance(struct XorrisO *xorriso, char *mode,
              (l ==  8 && strncmp(cpt, "emul_toc", l) == 0)) {
      xorriso->no_emul_toc&= ~1;
 
+   } else if((l == 13 && strncmp(cpt, "iso_9660_1999", l) == 0) ||
+             (l == 16 && strncmp(cpt, "iso_9660_1999_on", l) == 0)) {
+     xorriso->do_iso1999= 1;
+   } else if(l == 17 && strncmp(cpt, "iso_9660_1999_off", l) == 0) {
+     xorriso->do_iso1999= 0;
+
+   } else if((l >= 15 && strncmp(cpt, "iso_9660_level=", 15) == 0)) {
+     value= 0;
+     sscanf(cpt + 15, "%d", &value);
+     if(value == 1 || value == 2) {
+       limit= ((off_t) 4) * ((off_t) 1024*1024*1024) - ((off_t) 1);
+       xorriso->iso_level= value;
+       if(xorriso->file_size_limit > limit)
+         xorriso->file_size_limit= limit;
+     } else if(value == 3) {
+       xorriso->iso_level= value;
+       if(xorriso->file_size_limit < Xorriso_default_file_size_limiT)
+         xorriso->file_size_limit= Xorriso_default_file_size_limiT;
+     } else {
+       sprintf(msg,
+             "-compliance iso_9660_level=%d : Only 1, 2, or 3 are permissible",
+             value);
+       Xorriso_msgs_submit(xorriso, 0, msg, 0, "FAILURE", 0);
+       xorriso->relax_compliance= was;
+       return(0);
+     }
+
    } else if((l ==  8 && strncmp(cpt, "iso_9660", l) == 0) ||
              (l == 11 && strncmp(cpt, "iso_9660_on", l) == 0)) {
      /* may have a meaning in future */;
@@ -1923,6 +1995,8 @@ int Xorriso_relax_compliance(struct XorrisO *xorriso, char *mode,
      Xorriso_msgs_submit(xorriso, 0,
             "-compliance -iso_9660_off : Cannot do anything else but ISO 9660",
             0, "FAILURE", 0);
+     xorriso->relax_compliance= was;
+     return(0);
 
    } else {
      if(l<SfileadrL)
@@ -1952,6 +2026,10 @@ int Xorriso_get_relax_text(struct XorrisO *xorriso, char mode[1024],
    return(1);
  }
  strcpy(mode, "clear");
+ if(xorriso->iso_level != 3)
+   sprintf(mode + strlen(mode), ":iso_9660_level=%d",  xorriso->iso_level);
+ if(r & isoburn_igopt_allow_dir_id_ext)
+   strcat(mode, ":allow_dir_id_ext");
  if(r & isoburn_igopt_omit_version_numbers)
    strcat(mode, ":omit_version");
  if(r & isoburn_igopt_only_iso_versions)
@@ -1987,9 +2065,15 @@ int Xorriso_get_relax_text(struct XorrisO *xorriso, char mode[1024],
  }
  if(xorriso->no_emul_toc & 1)
    strcat(mode, ":no_emul_toc");
-
+ if(xorriso->untranslated_name_len != 0)
+   sprintf(mode + strlen(mode), ":untranslated_name_len=%d",
+           xorriso->untranslated_name_len);
+ if(xorriso->do_iso1999)
+   sprintf(mode + strlen(mode), ":iso_9660_1999");
  return(1 +
-       (r == Xorriso_relax_compliance_defaulT && !(xorriso->no_emul_toc & 1)));
+       (r == Xorriso_relax_compliance_defaulT && !(xorriso->no_emul_toc & 1)
+        && xorriso->untranslated_name_len == 0 && !xorriso->do_iso1999 &&
+        xorriso->iso_level == 3));
 }
 
 
