@@ -2,7 +2,7 @@
 /* Command line oriented batch and dialog tool which creates, loads,
    manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2010 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -123,7 +123,9 @@ struct XorrisO { /* the global context of xorriso */
                             Do not create or use hln arrays if sort_lba_on
                     */
 
+ int iso_level;
  int do_joliet;
+ int do_iso1999;
 
  int do_aaip; /* bit0= ACL in
                  bit1= ACL out
@@ -154,6 +156,7 @@ struct XorrisO { /* the global context of xorriso */
  char scdbackup_tag_listname[SfileadrL];
 
  int relax_compliance;        /* opaque bitfield to be set by xorrisoburn */
+ int untranslated_name_len;
  int do_follow_pattern;
  int do_follow_param;
  int do_follow_links;
@@ -479,6 +482,7 @@ struct XorrisO { /* the global context of xorriso */
  int library_msg_direct_print;
  char abort_on_text[20];
  int abort_on_severity; /* A severity rank number as threshold */
+ int abort_on_is_default; /* will be set to 0 by first -abort_on */
  int problem_status; /* Severity rank number. 0= no abort condition present */
  char problem_status_text[20];
 
